import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import { useI18n } from '/@/hooks/web/useI18n';
import { isEmpty, isNullOrEmpty, isNullOrUnDef, isNumber, isObject, isString } from '/@/utils/is';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';
import { useMessage } from '/@/hooks/web/useMessage';
import { Data_Types } from '/@/enums/tiger/dataTypes';
import { Rule_Types } from '/@/enums/tiger/ruleTypes';
import { PrefixInteger } from '/@/utils/prefixInteger';
//列表显示
export const dtlColumns: BasicColumn[] = [
  {
    title: '规则编码',
    dataIndex: 'RULE_ID',
    ifShow: false,
    width: 180,
  },
  {
    title: '明细描述',
    dataIndex: 'DESCRIPTION',
  },
  {
    title: '数据类型',
    dataIndex: 'DATA_TYPE',
    customRender: ({ record }) => {
      const type = record.DATA_TYPE;
      var text = '';
      var color = 'blue';
      switch (type) {
        case Data_Types.Character:
          text = '纯字母';
          break;
        case Data_Types.Numeric:
          text = '纯数字';
          color = 'yellow';
          break;
        case Data_Types.DateCode:
          text = '日期';
          color = 'orange';
          break;
        case Data_Types.TimeCode:
          text = '时间';
          color = '#bfbfbf';
          break;
        case Data_Types.DbCheck:
          text = '关联校验';
          color = '#0b9da9';
          break;
        case Data_Types.FixedCode:
          text = '固定值';
          color = 'green';
          break;
        case Data_Types.SerialCode:
          text = '流水号';
          color = '#b442df';
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    title: '校验位数',
    dataIndex: 'CHECK_LENGTH',
  },
  {
    title: '校验位数',
    dataIndex: 'CHECK_LENGTH',
  },
  {
    title: '匹配次数',
    dataIndex: 'REPEAT_TIMES',
  },
  {
    title: '校验范围',
    dataIndex: 'DATA_RANGE',
    customRender: ({ record }) => {
      const type = record.DATA_TYPE;
      var text = '';
      var color = 'blue';
      switch (type) {
        case Data_Types.Character:
        case Data_Types.Numeric:
        case Data_Types.DateCode:
        case Data_Types.TimeCode:
          text = record.DATA_CASE;
          break;
        case Data_Types.DbCheck:
        case Data_Types.FixedCode:
          text = record.DATA_VALUE;
          break;
        case Data_Types.SerialCode:
          text = `${PrefixInteger(record.SERIAL_MIN, record.CHECK_LENGTH)}-${PrefixInteger(record.SERIAL_MAX, record.CHECK_LENGTH)}`;
          break;
      }
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    title: '校验表达式',
    dataIndex: 'DATA_REGEX',
  },
  {
    title: '备注',
    dataIndex: 'REMARK',
  },
  {
    title: 'DATA_TYPE',
    dataIndex: 'DATA_TYPE',
    ifShow: false,
  },
  {
    title: 'DATA_VALUE',
    dataIndex: 'DATA_VALUE',
    ifShow: false,
  },
  {
    title: '更新时间',
    dataIndex: 'UPDATE_TIME',
  },
  {
    title: '更新人',
    dataIndex: 'UPDATE_USER',
  },
];

export const columns: BasicColumn[] = [
  {
    title: '规则编码',
    dataIndex: 'RULE_CODE',
    width: 180,
  },
  {
    title: '规则名称',
    dataIndex: 'RULE_NAME',
  },
  {
    title: '规则描述',
    dataIndex: 'RULE_DESC',
  },
  {
    title: '条码位数',
    dataIndex: 'CODE_LENGTH',
  },
  {
    title: '校验类型',
    dataIndex: 'CHECK_TYPE',
  },
  {
    title: '校验表达式',
    dataIndex: 'CHECK_REGEX',
  },
  {
    title: '备注',
    dataIndex: 'REMARK',
  },
  {
    title: '更新时间',
    dataIndex: 'UPDATE_TIME',
  },
  {
    title: '更新人',
    dataIndex: 'UPDATE_USER',
  },
];
//模糊查询
export const searchFormSchema: FormSchema[] = [
  {
    field: 'RULE_CODE',
    label: '规则编码',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'ITEM_CODE',
    label: '物料编码',
    component: 'Input',
    colProps: { span: 8 },
  },
];
//新增规则明细
const isLetter = (type: number) => type === 0;
const isNum = (type: number) => type === 1;
const isFixed = (type: number) => type === 2;
const isDate = (type: number) => type === 4;
const isTime = (type: number) => type === 5;
const isRelated = (type: number) => type === 6;
const isNoCheck = (type: number) => type === 7;
const isSerial = (type: number) => type === 3;
const { t } = useI18n();
// const { notification, createErrorModal } = useMessage();
export const formSchema: FormSchema[] = [
  {
    field: 'DATA_TYPE',
    label: '校验规则类型',
    component: 'RadioButtonGroup',
    defaultValue: 0,
    componentProps: ({ schema, tableAction, formActionType, formModel }) => {
      return {
        options: [
          { label: '纯字母', value: Data_Types.Character },
          { label: '纯数字', value: Data_Types.Numeric },
          { label: '固定值', value: Data_Types.FixedCode },
          { label: '流水号', value: Data_Types.SerialCode },
          { label: '日期', value: Data_Types.DateCode },
          { label: '时间', value: Data_Types.TimeCode },
          { label: '关联校验', value: Data_Types.DbCheck },
          { label: '不校验', value: Data_Types.NoCheck },
        ],
        onChange: (e) => {
          formModel.DATA_CASE = null;
          formModel.DATE_CASE = null;
          formModel.TIME_CASE = null;
          // formModel.DATA_RANGE = '';
          // formModel.DATA_REGEX = '';
          if (e == Data_Types.Character) {
            // formModel.DATA_RANGE = '0-9';
            formModel.DATA_REGEX = `([${formModel.DATA_CASE}]{${formModel.CHECK_LENGTH}}){${formModel.REPEAT_TIMES}}`;
          }
          if (e == Data_Types.Numeric) {
            formModel.DATA_CASE = '0-9';
            formModel.DATA_RANGE = '0-9';
            formModel.DATA_REGEX = `([0-9]{${formModel.CHECK_LENGTH}}){${formModel.REPEAT_TIMES}}`;
          }

          if (e == Data_Types.FixedCode) {
            formModel.DATA_VALUE = '';
            formModel.DATA_RANGE = formModel.DATA_VALUE;
            formModel.DATA_REGEX = `(${formModel.DATA_VALUE.replace(',', '|')}){${
              formModel.REPEAT_TIMES
            }}`;
          }
          if (e == Data_Types.FixedCode || e == Data_Types.DateCode || e == Data_Types.TimeCode) {
            formModel.DATA_VALUE = '';
            formModel.CHECK_LENGTH = '';
          }
          if (e == Data_Types.DbCheck || e == Data_Types.NoCheck) {
            formModel.DATA_REGEX =
              formModel.CHECK_LENGTH > 0
                ? `(.{${formModel.CHECK_LENGTH}}){${formModel.REPEAT_TIMES}}`
                : `(.*){${formModel.REPEAT_TIMES}}`;
          }
          if (e == Data_Types.SerialCode) {
            formModel.DATA_REGEX = `([0-9]{${formModel.CHECK_LENGTH}}){${formModel.REPEAT_TIMES}}`;
          }
        },
      };
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'DATA_CASE',
    label: '规则类型',
    required: true,
    component: 'Select',
    colProps: { span: 12 },
    componentProps: ({ schema, tableAction, formActionType, formModel }) => {
      return {
        options: [
          {
            label: '全大写',
            value: 'A-Z',
            key: '0',
          },
          {
            label: '全小写',
            value: 'a-z',
            key: '1',
          },
          {
            label: '不限制',
            value: 'A-Za-z',
            key: '2',
          },
        ],
        // xxxx props
        onChange: (e) => {
          if (isLetter(formModel.DATA_TYPE)) {
            switch (e) {
              case 'A-Z':
                formModel.DATA_RANGE = 'A-Z';
                formModel.DATA_REGEX = `([A-Z]{${formModel.CHECK_LENGTH}}){${formModel.REPEAT_TIMES}}`;
                break;
              case 'a-z':
                formModel.DATA_RANGE = 'a-z';
                formModel.DATA_REGEX = `([a-z]{${formModel.CHECK_LENGTH}}){${formModel.REPEAT_TIMES}}`;
                break;
              case 'A-Za-z':
                formModel.DATA_RANGE = 'A-Za-z';
                formModel.DATA_REGEX = `([A-Za-z]{${formModel.CHECK_LENGTH}}){${formModel.REPEAT_TIMES}}`;
                break;
            }
          }
        },
      };
    },
    ifShow: ({ values }) => isLetter(values.DATA_TYPE),
  },
  {
    field: 'DATA_CASE',
    label: '规则类型',
    required: true,
    component: 'Select',
    colProps: { span: 12 },
    componentProps: ({ schema, tableAction, formActionType, formModel }) => {
      return {
        options: [
          {
            label: '年（yyyy）',
            value: 'yyyy',
            key: '0',
          },
          {
            label: '年（yy）',
            value: 'yy',
            key: '1',
          },
          {
            label: '季（q）',
            value: 'q',
            key: '2',
          },
          {
            label: '月（mm）',
            value: 'mm',
            key: '3',
          },
          {
            label: '月（m）',
            value: 'm',
            key: '4',
          },
          {
            label: '周（ww）',
            value: 'ww',
            key: '5',
          },
          {
            label: '周几（dy）',
            value: 'dy',
            key: '6',
          },
          {
            label: '日（dd）',
            value: 'dd',
            key: '7',
          },
        ],
        onChange: (e) => {
          formModel.DATA_RANGE = e;
          let _regex = '';
          switch (e) {
            case 'yyyy':
              _regex = '\\d{4}';
              formModel.CHECK_LENGTH = 4;
              break;
            case 'yy':
              _regex = '\\d{2}';
              formModel.CHECK_LENGTH = 2;
              break;
            case 'q':
              _regex = '[1-4]';
              formModel.CHECK_LENGTH = 1;
              break;
            case 'mm':
              _regex = '0[1-9]|1[0-2]';
              formModel.CHECK_LENGTH = 2;
              break;
            case 'm':
              _regex = '[1-9ABC]';
              formModel.CHECK_LENGTH = 1;
              break;
            case 'ww':
              _regex = '0[1-9]|[1-4][0-9]|(5[0-3])';
              formModel.CHECK_LENGTH = 2;
              break;
            case 'dy':
              _regex = '[1-7]';
              formModel.CHECK_LENGTH = 2;
              break;
            case 'dd':
              _regex = '0[1-9]|[1-2][0-9]|3[0-1]';
              formModel.CHECK_LENGTH = 2;
              break;
          }
          formModel.DATA_REGEX = `(${_regex}){${formModel.REPEAT_TIMES}}`;
        },
      };
    },
    ifShow: ({ values }) => isDate(values.DATA_TYPE),
  },
  {
    field: 'DATA_CASE',
    label: '规则类型',
    required: true,
    component: 'Select',
    colProps: { span: 12 },
    componentProps: ({ schema, tableAction, formActionType, formModel }) => {
      return {
        options: [
          {
            label: '时',
            value: 'hh',
            key: '0',
          },
          {
            label: '分',
            value: 'mi',
            key: '1',
          },
          {
            label: '秒',
            value: 'ss',
            key: '2',
          },
          {
            label: '毫秒',
            value: 'fff',
            key: '3',
          },
        ],
        onChange: (e) => {
          formModel.DATA_RANGE = e;
          let _regex = '';
          switch (e) {
            case 'hh':
              _regex = '[0-1][0-9]|2[0-3]';
              formModel.CHECK_LENGTH = 2;
              break;
            case 'mi':
              _regex = '[0-5][0-9]';
              formModel.CHECK_LENGTH = 2;
              break;
            case 'ss':
              _regex = '[0-5][0-9]';
              formModel.CHECK_LENGTH = 2;
              break;
            case 'fff':
              _regex = '[0-9]{3}';
              formModel.CHECK_LENGTH = 3;
              break;
          }
          formModel.DATA_REGEX = `(${_regex}){${formModel.REPEAT_TIMES}}`;
        },
      };
    },
    ifShow: ({ values }) => isTime(values.DATA_TYPE),
  },
  {
    field: 'DATA_CASE',
    label: '规则类型',
    required: true,
    component: 'Select',
    colProps: { span: 12 },
    componentProps: ({ schema, tableAction, formActionType, formModel }) => {
      return {
        options: [
          {
            label: '纯数字',
            value: '0-9',
            key: '0',
          },
        ],
        // xxxx props
        onChange: (e) => {
          if (isNum(formModel.DATA_TYPE)) {
            formModel.DATA_RANGE = '0-9';
            formModel.DATA_REGEX = `([0-9]{${formModel.CHECK_LENGTH}}){${formModel.REPEAT_TIMES}}`;
          }
        },
      };
    },
    ifShow: ({ values }) => isNum(values.DATA_TYPE),
  },
  {
    field: 'CHECK_TABLE',
    label: '表名',
    required: false,
    component: 'Input',
    colProps: { span: 12 },
    ifShow: ({ values }) => isRelated(values.DATA_TYPE),
  },
  {
    field: 'ID',
    label: 'ID',
    component: 'Input',
    show: false,
  },
  {
    field: 'CHECK_FIELD',
    label: '字段名',
    component: 'Input',
    show: true,
    colProps: { span: 12 },
    componentProps: ({ schema, tableAction, formActionType, formModel }) => {
      return {
        onChange: (e) => {
          var val = typeof e == 'object' && e != null ? e.target.value : e;
          if (isRelated(formModel.DATA_TYPE)) {
            formModel.DATA_RANGE = `${formModel.CHECK_TABLE}.${val}`;
            formModel.DATA_VALUE = `${formModel.CHECK_TABLE}.${val}`;
          }
        },
      };
    },
    ifShow: ({ values }) => isRelated(values.DATA_TYPE),
  },
  {
    field: 'DATA_VALUE',
    label: '值',
    required: true,
    defaultValue: '1',
    component: 'Input',
    colProps: { span: 12 },
    dynamicDisabled: ({ values }) => {
      return true;
    },
    ifShow: ({ values }) => isRelated(values.DATA_TYPE),
  },
  {
    field: 'DATA_VALUE',
    label: '固定值',
    required: true,
    defaultValue: '1',
    component: 'Input',
    colProps: { span: 12 },
    componentProps: ({ schema, tableAction, formActionType, formModel }) => {
      return {
        onChange: (e) => {
          var val = typeof e == 'object' && e != null ? e.target.value : e;
          if (isFixed(formModel.DATA_TYPE)) {
            formModel.DATA_RANGE = val;
            formModel.DATA_REGEX = isString(e)
              ? e
              : `(${e.target.value.replace(new RegExp(',', 'g'), '|')}){${formModel.REPEAT_TIMES}}`;

            var _length = e.target.value.split(',').reduce((length, str) => {
              if (length == 0) {
                return str.length;
              } else {
                return length === str.length ? str.length : -1;
              }
              // return Math.max(maxLength, str.length);
            }, 0);
            formModel.CHECK_LENGTH = _length;
            if (formModel.FIXED_NOTLIKE == 'Y') {
              formModel.DATA_RANGE = `${val}`;
              formModel.DATA_REGEX = `([^${e.target.value.replace(new RegExp(',', 'g'), '|')}]{${formModel.CHECK_LENGTH}}){${formModel.REPEAT_TIMES}}`;
            }
          }
        },
      };
    },
    rules: [
      {                                                                                                                                
        required: true,
        // @ts-ignore
        validator: async (rule, value) => {
          var _length = value.split(',').reduce((length, str) => {
            if (length == 0) {
              return str.length;
            } else {
              return length == str.length ? str.length : -1;
            }
            // return Math.max(maxLength, str.length);
          }, 0);
          if (!value) {
            /* eslint-disable-next-line */
            return Promise.reject(t('固定值不能为空'));
          }
          if (_length === -1) {
            /* eslint-disable-next-line */
            return Promise.reject(t('固定值必需长度一样'));
          }
          return Promise.resolve();
        },
        trigger: 'change',
      },
    ],
    ifShow: ({ values }) => isFixed(values.DATA_TYPE),
  },
  {
    field: 'CHECK_LENGTH',
    label: '检验长度',
    defaultValue: '1',
    required: true,
    component: 'Input',
    colProps: { span: 12 },
    componentProps: ({ schema, tableAction, formActionType, formModel }) => {
      return {
        onChange: (e) => {
          var val = typeof e == 'object' && e != null ? e.target.value : e;
          if (formModel.DATA_TYPE == Data_Types.Character) {
            switch (e) {
              case '0':
                formModel.DATA_RANGE = 'A-Z';
                break;
              case '1':
                formModel.DATA_RANGE = 'a-z';
                break;
              case '2':
                formModel.DATA_RANGE = 'A-Za-z';
                break;
            }
            formModel.DATA_REGEX = `([${formModel.DATA_RANGE}]{${val}}){${formModel.REPEAT_TIMES}}`;
          }
          if (formModel.DATA_TYPE == Data_Types.Numeric) {
            formModel.DATA_REGEX = `([${formModel.DATA_RANGE}]{${val}}){${formModel.REPEAT_TIMES}}`;
          }
          if (formModel.DATA_TYPE == Data_Types.FixedCode) {
            formModel.DATA_REGEX = `(${formModel.DATA_RANGE.replace(new RegExp(',', 'g'), '|')}){${
              formModel.REPEAT_TIMES
            }}`;
          }

          if (formModel.DATA_TYPE == Data_Types.DateCode) {
            if (!isNullOrEmpty(formModel.DATE_CASE)) {
              formModel.DATA_RANGE = formModel.DATE_CASE;
              let _regex = '';
              switch (formModel.DATA_RANGE) {
                case 'yyyy':
                  _regex = '\\d{4}';
                  break;
                case 'yy':
                  _regex = '\\d{2}';
                  break;
                case 'q':
                  _regex = '[1-4]';
                  break;
                case 'mm':
                  _regex = '0[1-9]|1[0-2]';
                  break;
                case 'm':
                  _regex = '[1-9ABC]';
                  break;
                case 'ww':
                  _regex = '0[1-9]|[1-4][0-9]|(5[0-3])';
                  break;
                case 'dy':
                  _regex = '[1-7]';
                  break;
                case 'dd':
                  _regex = '0[1-9]|[1-2][0-9]|3[0-1]';
                  break;
              }
              formModel.DATA_REGEX = `(${_regex}){${formModel.REPEAT_TIMES}}`;
            }
          }
          if (formModel.DATA_TYPE == Data_Types.TimeCode) {
            if (!isNullOrEmpty(formModel.TIME_CASE)) {
              let _regex = '';
              switch (e) {
                case 'hh':
                  _regex = '[0-1][0-9]|2[0-3]';
                  break;
                case 'mi':
                  _regex = '[0-5][0-9]';
                  break;
                case 'ss':
                  _regex = '[0-5][0-9]';
                  break;
                case 'fff':
                  _regex = '[0-9]{3}';
                  break;
              }
              formModel.DATA_REGEX = `(${_regex}){${formModel.REPEAT_TIMES}}`;
            }
          }
          //formModel.CHECK_LENGTH>0? `(.{${formModel.CHECK_LENGTH}}){${formModel.REPEAT_TIMES}}`: `(.*){${formModel.REPEAT_TIMES}}`;
          if (formModel.DATA_TYPE == Data_Types.DbCheck) {
            formModel.DATA_REGEX =
              val > 0
                ? `(.{${val}}){${formModel.REPEAT_TIMES}}`
                : `(.*){${formModel.REPEAT_TIMES}}`;
          }
          if (formModel.DATA_TYPE == Data_Types.NoCheck) {
            formModel.DATA_REGEX = `(.{${val}}){${formModel.REPEAT_TIMES}}`;
          }
          if (formModel.DATA_TYPE == Data_Types.SerialCode) {
            if (!isNullOrEmpty(formModel.SERIAL_MAX) && !isNullOrEmpty(formModel.SERIAL_MIN)) {
              if (isNaN(Number(val)) || isNullOrEmpty(val)) {
              } else {
                var min = PrefixInteger(formModel.SERIAL_MIN, Number(val));
                var max = PrefixInteger(formModel.SERIAL_MAX, Number(val));
                formModel.DATA_RANGE = `${min}-${max}`;
              }
            }
            formModel.DATA_REGEX = `([0-9]{${val}}){${formModel.REPEAT_TIMES}}`;
          }
        },
      };
    },
    rules: [
      {
        required: true,
        // @ts-ignore
        validator: async (rule, value) => {
          if (!value) {
            /* eslint-disable-next-line */
            return Promise.reject(t('检验长度不能为空'));
          }
          if (isNaN(Number(value))) {
            return Promise.reject(t('检验长度不是数字'));
          }
          return Promise.resolve();
        },
        trigger: 'change',
      },
    ],
    // ifShow: ({ values }) => !isDate(values.DATA_TYPE) && !isTime(values.DATA_TYPE),

    dynamicDisabled: ({ values }) => {
      return isDate(values.DATA_TYPE) || isTime(values.DATA_TYPE) || isFixed(values.DATA_TYPE);
    },
  },
  {
    field: 'REPEAT_TIMES',
    label: '匹配次数',
    required: true,
    defaultValue: '1',
    component: 'Input',
    colProps: { span: 12 },
    componentProps: ({ schema, tableAction, formActionType, formModel }) => {
      return {
        onChange: (e) => {
          var val = typeof e == 'object' && e != null ? e.target.value : e;
          if (formModel.DATA_TYPE == Data_Types.Character) {
            formModel.DATA_REGEX = `([${formModel.DATA_RANGE}]{${formModel.CHECK_LENGTH}}){${val}}`;
          }
          if (formModel.DATA_TYPE == Data_Types.Numeric) {
            formModel.DATA_REGEX = `([${formModel.DATA_RANGE}]{${formModel.CHECK_LENGTH}}){${val}}`;
          }
          if (formModel.DATA_TYPE == Data_Types.FixedCode) {
            formModel.DATA_REGEX = `(${formModel.DATA_RANGE.replace(',', '|')}){${val}}`;
          }

          if (formModel.DATA_TYPE == Data_Types.DateCode) {
            if (!isNullOrEmpty(formModel.DATA_CASE)) {
              formModel.DATA_RANGE = formModel.DATA_CASE;
              let _regex = '';
              switch (formModel.DATA_RANGE) {
                case 'yyyy':
                  _regex = '\\d{4}';
                  break;
                case 'yy':
                  _regex = '\\d{2}';
                  break;
                case 'q':
                  _regex = '[1-4]';
                  break;
                case 'mm':
                  _regex = '0[1-9]|1[0-2]';
                  break;
                case 'm':
                  _regex = '[1-9ABC]';
                  break;
                case 'ww':
                  _regex = '0[1-9]|[1-4][0-9]|(5[0-3])';
                  break;
                case 'dy':
                  _regex = '[1-7]';
                  break;
                case 'dd':
                  _regex = '0[1-9]|[1-2][0-9]|3[0-1]';
                  break;
              }
              formModel.DATA_REGEX = `(${_regex}){${val}}`;
            }
          }
          if (formModel.DATA_TYPE == Data_Types.TimeCode) {
            if (!isNullOrEmpty(formModel.DATA_CASE)) {
              let _regex = '';
              switch (formModel.DATA_RANGE) {
                case 'hh':
                  _regex = '[0-1][0-9]|2[0-3]';
                  break;
                case 'mi':
                  _regex = '[0-5][0-9]';
                  break;
                case 'ss':
                  _regex = '[0-5][0-9]';
                  break;
                case 'fff':
                  _regex = '[0-9]{3}';
                  break;
              }
              formModel.DATA_REGEX = `(${_regex}){${val}}`;
            }
          }
          if (formModel.DATA_TYPE == 6 || formModel.DATA_TYPE == 7) {
            formModel.DATA_REGEX = `(.{${formModel.CHECK_LENGTH}}){${val}}`;
          }
          if (formModel.DATA_TYPE == 3) {
            formModel.DATA_REGEX = `([0-9]{${formModel.CHECK_LENGTH}}){${val}}`;
          }
        },
      };
    },
  },
  {
    field: 'SERIAL_MIN',
    label: '序列号从',
    component: 'Input',
    required: true,
    show: true,
    colProps: { span: 12 },
    componentProps: ({ schema, tableAction, formActionType, formModel }) => {
      return {
        onChange: (e) => {
          if (isSerial(formModel.DATA_TYPE)) {
            var val = typeof e == 'object' && e != null ? e.target.value : e;
            if (!isNullOrEmpty(formModel.SERIAL_MAX)) {
              if (isNaN(Number(formModel.CHECK_LENGTH)) || isNullOrEmpty(formModel.CHECK_LENGTH)) {
              } else {
                var min = PrefixInteger(val, Number(formModel.CHECK_LENGTH));
                var max = PrefixInteger(formModel.SERIAL_MAX, Number(formModel.CHECK_LENGTH));
                formModel.DATA_RANGE = `${min}-${max}`;
              }
            }
          }
        },
      };
    },
    rules: [
      {
        required: true,
        // @ts-ignore
        validator: async (rule, value) => {
          if (!value) {
            /* eslint-disable-next-line */
            return Promise.reject(t('序列号起始值不能为空'));
          }
          if (isNaN(Number(value))) {
            return Promise.reject(t('序列号起始值不是数字'));
          }
          return Promise.resolve();
        },
        trigger: 'change',
      },
    ],
    ifShow: ({ values }) => isSerial(values.DATA_TYPE),
  },
  {
    field: 'SERIAL_MAX',
    label: '到',
    component: 'Input',
    required: true,
    show: true,
    colProps: { span: 12 },
    componentProps: ({ schema, tableAction, formActionType, formModel }) => {
      return {
        onChange: (e) => {
          if (isSerial(formModel.DATA_TYPE)) {
            var val = typeof e == 'object' && e != null ? e.target.value : e;
            if (!isNullOrEmpty(formModel.SERIAL_MIN)) {
              if (
                isNaN(Number(formModel.CHECK_LENGTH)) ||
                isNullOrUnDef(formModel.CHECK_LENGTH) ||
                isEmpty(formModel.CHECK_LENGTH)
              ) {
              } else {
                var min = PrefixInteger(formModel.SERIAL_MIN, Number(formModel.CHECK_LENGTH));
                var max = PrefixInteger(val, Number(formModel.CHECK_LENGTH));
                formModel.DATA_RANGE = `${min}-${max}`;
                formModel.DATA_VALUE = `${min}-${max}`;
              }
            }
          }
        },
      };
    },
    rules: [
      {
        required: true,
        // @ts-ignore
        validator: async (rule, value) => {
          if (!value) {
            /* eslint-disable-next-line */
            return Promise.reject(t('序列号结束值不能为空'));
          }
          if (isNaN(Number(value))) {
            return Promise.reject(t('序列号结束值不是数字'));
          }
          return Promise.resolve();
        },
        trigger: 'change',
      },
    ],
    ifShow: ({ values }) => isSerial(values.DATA_TYPE),
  },
  {
    field: 'FIXED_NOTLIKE',
    label: '是否不包含固定值',
    required: true,
    component: 'Select',
    colProps: { span: 12 },
    componentProps: ({ schema, tableAction, formActionType, formModel }) => {
      return {
        options: [
          {
            label: '是',
            value: 'Y',
          },
          {
            label: '否',
            value: 'N',
          },
        ],
        onChange: (e) => {
          if (isFixed(formModel.DATA_TYPE)) {
            var val = typeof e == 'object' && e != null ? e.target.value : e;
            formModel.DATA_RANGE =val == 'N'? formModel.DATA_VALUE: `${formModel.DATA_VALUE}`;
            formModel.DATA_REGEX =
              val == 'N'
                ? `(${formModel.DATA_VALUE.replace(new RegExp(',', 'g'), '|')}){${formModel.REPEAT_TIMES}}`
                : `([^${formModel.DATA_VALUE.replace(new RegExp(',', 'g'), '|')}]{${formModel.CHECK_LENGTH}}){${formModel.REPEAT_TIMES}}`;
          }
        },
      };
    },
    ifShow: ({ values }) => isFixed(values.DATA_TYPE),
  },
  {
    field: 'SERIAL_INTERVAL',
    label: '流水号取号间隔',
    component: 'Input',
    dynamicRules: ({ values }) => {
      return [
        {
          required: true,
          validator: (_, value) => {
            if (!value) {
              return Promise.reject('流水号取号间隔不能为空!');
            }
            if (!isNumber(value)) {
              return Promise.reject('请输入数字!');
            }
            if (Number(value) < 0) {
              return Promise.reject('必需输入大于0的数字!');
            }
            return Promise.resolve();
          },
        },
      ];
    },
    show: true,
    colProps: { span: 12 },
    dynamicDisabled: ({ values }) => {
      return false;
    },
    ifShow: ({ values }) => isSerial(values.DATA_TYPE),
  },
  {
    field: 'SERIAL_IGNORE',
    label: '流水号跳号',
    component: 'Input',
    // required: true,
    show: true,
    colProps: { span: 24 },
    ifShow: ({ values }) => isSerial(values.DATA_TYPE),
  },
  {
    field: 'DATA_RANGE',
    label: '校验范围',
    component: 'Input',
    show: true,
    colProps: { span: 24 },
    dynamicDisabled: ({ values }) => {
      return true;
    },
  },
  {
    field: 'DATA_REGEX',
    label: '表达式',
    component: 'Input',
    show: true,
    colProps: { span: 24 },
    dynamicDisabled: ({ values }) => {
      return true;
    },
  },
  {
    field: 'DESCRIPTION',
    label: '明细描述',
    component: 'Input',
    show: true,
    colProps: { span: 24 },
  },
  {
    field: 'ID',
    label: 'ID',
    component: 'Input',
    show: false,
    colProps: { span: 12 },
  },
  {
    field: 'RULE_ID',
    label: 'RULE_ID',
    component: 'Input',
    show: false,
    colProps: { span: 12 },
  },
  {
    field: 'RULE_SEQ',
    label: 'RULE_SEQ',
    component: 'Input',
    defaultValue: 1,
    show: false,
    colProps: { span: 12 },
  },
];

export const newFormSchema: FormSchema[] = [
  {
    field: 'RULE_CODE',
    label: '规则编码',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
    dynamicDisabled: ({ values }) => {
      return !isNullOrEmpty(values.ID);
    },
  },
  {
    field: 'RULE_NAME',
    label: '规则名称',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'RULE_DESC',
    label: '规则描述',
    required: false,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'RULE_TYPE',
    label: '规则类型',
    required: true,
    component: 'Select',
    colProps: { span: 8 },
    componentProps: ({ schema, tableAction, formActionType, formModel }) => {
      return {
        options: [
          { label: '物料条码', value: Rule_Types.Material },
          { label: '半成品条码', value: Rule_Types.SemiProduct },
          { label: '成品条码', value: Rule_Types.Product },
          { label: '单据号码', value: Rule_Types.BizOrder },
        ],
      };
    },
  },
  {
    field: 'CODE_LENGTH',
    label: '条码长度',
    component: 'Input',
    colProps: { span: 8 },
    dynamicDisabled: ({ values }) => {
      return true;
    },
  },
  {
    field: 'CHECK_TYPE',
    label: '校验类型',
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        {
          label: '自身校验',
          value: 0,
          key: '0',
        },
        {
          label: '关联校验',
          value: 1,
          key: '1',
        },
      ],
    },
    dynamicDisabled: ({ values }) => {
      return true;
    },
  },
  {
    field: 'ID',
    label: 'ID',
    component: 'Input',
    show: false,
    colProps: { span: 8 },
  },
];

export const testSchemas: FormSchema[] = [
  {
    field: 'CHECK_REGEX',
    label: '校验表达式',
    required: true,
    component: 'Input',
    colProps: { span: 24 },
    dynamicDisabled: ({ values }) => {
      return true;
    },
  },
  {
    field: 'Test',
    label: '测试',
    component: 'Input',
    colProps: { span: 12 },
    componentProps: ({ schema, tableAction, formActionType, formModel }) => {
      return {
        onChange: (e) => {
          var val = typeof e == 'object' && e != null ? e.target.value : e;
          if (new RegExp(formModel.CHECK_REGEX).test(val)) {
            formModel.TestResult = '通过';
          } else {
            formModel.TestResult = '失败';
          }
        },
      };
    },
  },
  {
    field: 'TestResult',
    label: '测试结果',
    component: 'Input',
    colProps: { span: 12 },
    render: ({ model, field }) => {
      var text = model[field];
      var color = '';
      switch (text) {
        case '通过':
          color = 'green';
          break;
        case '失败':
          color = 'red';
          break;
      }
      return h(Tag, { color: color }, () => text);
    },

    dynamicDisabled: ({ values }) => {
      return true;
    },
  },
];
